@@ -1,6 +1,6 @@
 package WWW::Google::URLShortener::Analytics::Result::Platform;
 
-$WWW::Google::URLShortener::Analytics::Result::Platform::VERSION   = '0.20';
+$WWW::Google::URLShortener::Analytics::Result::Platform::VERSION   = '0.21';
 $WWW::Google::URLShortener::Analytics::Result::Platform::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ WWW::Google::URLShortener::Analytics::Result::Platform - Placeholder for the res
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
@@ -19,15 +19,14 @@ use overload q{""} => 'as_string', fallback => 1;
 use Moo;
 use namespace::clean;
 
+has [ qw(id count) ] => (is => 'ro');
+
 sub as_string {
     my ($self) = @_;
 
     return sprintf("Id: %s, Count: %d", $self->id, $self->count);
 }
 
-has id    => (is => 'ro');
-has count => (is => 'ro');
-
 =head1 METHODS
 
 =head2 id()
